tlslite.utils.OpenSSL_AES.OpenSSL_AES

Package tlslite :: Package utils :: Module OpenSSL_AES :: Class OpenSSL_AES |
[show private | hide private]
[frames | no frames]

## Class OpenSSL_AES

    AES --+
          |
         OpenSSL_AES

Method Summary
| `__init__(self, key, mode, IV)`
| `decrypt(self, ciphertext)`
| `encrypt(self, plaintext)`
| `_createContext(self, encrypt)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net